==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d0/dd7/toolbar__widget_8h.js <==
var toolbar__widget_8h =
[
    [ "ToolbarEditorWidgets", "d0/dd7/toolbar__widget_8h.html#a17f63f9c72242c80963576f4a0b97212", [
      [ "WID_TE_PAUSE", "d0/dd7/toolbar__widget_8h.html#a17f63f9c72242c80963576f4a0b97212a805ae41c8137a5d797a8b7e912957bf6", null ],
      [ "WID_TE_FAST_FORWARD", "d0/dd7/toolbar__widget_8h.html#a17f63f9c72242c80963576f4a0b97212ac382fd8c6ca0514d1ce3ffa68d12794b", null ],
      [ "WID_TE_SETTINGS", "d0/dd7/toolbar__widget_8h.html#a17f63f9c72242c80963576f4a0b97212adbc7e6bfe4a3baaa031baababef63794", null ],
      [ "WID_TE_SAVE", "d0/dd7/toolbar__widget_8h.html#a17f63f9c72242c80963576f4a0b97212aa06efa62603dc3fcf7c7ad95b1133e14", null ],
      [ "WID_TE_SPACER", "d0/dd7/toolbar__widget_8h.html#a17f63f9c72242c80963576f4a0b97212a926fee6779bef9d3efaba8a5e877de71", null ],
      [ "WID_TE_DATE", "d0/dd7/toolbar__widget_8h.html#a17f63f9c72242c80963576f4a0b97212a449d244085ae7c380674dda54af4e907", null ],
      [ "WID_TE_DATE_BACKWARD", "d0/dd7/toolbar__widget_8h.html#a17f63f9c72242c80963576f4a0b97212af8db533879680a24e5d7bbf967c7c175", null ],
      [ "WID_TE_DATE_FORWARD", "d0/dd7/toolbar__widget_8h.html#a17f63f9c72242c80963576f4a0b97212a8ba2c217d52f421165e0ac0a4bfa4b07", null ],
      [ "WID_TE_SMALL_MAP", "d0/dd7/toolbar__widget_8h.html#a17f63f9c72242c80963576f4a0b97212a106965d81aa71b896943c76872d95ae4", null ],
      [ "WID_TE_ZOOM_IN", "d0/dd7/toolbar__widget_8h.html#a17f63f9c72242c80963576f4a0b97212a6ba70ed149bedaf0536939b5ff021487", null ],
      [ "WID_TE_ZOOM_OUT", "d0/dd7/toolbar__widget_8h.html#a17f63f9c72242c80963576f4a0b97212a773968404d558061e77747f74691c08b", null ],
      [ "WID_TE_LAND_GENERATE", "d0/dd7/toolbar__widget_8h.html#a17f63f9c72242c80963576f4a0b97212aa3a1e59d7e7623e673d6b93801a2a93e", null ],
      [ "WID_TE_TOWN_GENERATE", "d0/dd7/toolbar__widget_8h.html#a17f63f9c72242c80963576f4a0b97212aa757913f6adbd97afd7ec6ae30c22c2b", null ],
      [ "WID_TE_INDUSTRY", "d0/dd7/toolbar__widget_8h.html#a17f63f9c72242c80963576f4a0b97212a7fcfbe6deb0438f200108245c300ffd3", null ],
      [ "WID_TE_ROADS", "d0/dd7/toolbar__widget_8h.html#a17f63f9c72242c80963576f4a0b97212aaa20746aa0a5d3f13794c51c1fb92eb8", null ],
      [ "WID_TE_WATER", "d0/dd7/toolbar__widget_8h.html#a17f63f9c72242c80963576f4a0b97212a94e700a5d6208bc0e8c1e9f3b172c6a5", null ],
      [ "WID_TE_TREES", "d0/dd7/toolbar__widget_8h.html#a17f63f9c72242c80963576f4a0b97212a148b4de732fe9bd096160c62fd1581ec", null ],
      [ "WID_TE_SIGNS", "d0/dd7/toolbar__widget_8h.html#a17f63f9c72242c80963576f4a0b97212ac590e6eec7efd51418d908421a318955", null ],
      [ "WID_TE_DATE_PANEL", "d0/dd7/toolbar__widget_8h.html#a17f63f9c72242c80963576f4a0b97212a6cbb415b5d9b075b02017e3e6199286f", null ],
      [ "WID_TE_MUSIC_SOUND", "d0/dd7/toolbar__widget_8h.html#a17f63f9c72242c80963576f4a0b97212a9b6f8a8f6fe85ad3aa4f7f5305a7ed4d", null ],
      [ "WID_TE_HELP", "d0/dd7/toolbar__widget_8h.html#a17f63f9c72242c80963576f4a0b97212a7259c24eb56d2f905e182ab0cd1fd643", null ],
      [ "WID_TE_SWITCH_BAR", "d0/dd7/toolbar__widget_8h.html#a17f63f9c72242c80963576f4a0b97212aa8245149e19ec5edb3ebaac63f4fc348", null ]
    ] ],
    [ "ToolbarNormalWidgets", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6d", [
      [ "WID_TN_PAUSE", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6dac08e4702de3440ac7d554be92cd6ad72", null ],
      [ "WID_TN_FAST_FORWARD", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6dabe5f09227a9d3d057c491f81deed8b45", null ],
      [ "WID_TN_SETTINGS", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6da0c055f87c6e8e0064475cbfb3f9f9beb", null ],
      [ "WID_TN_SAVE", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6da3cdb40d6ef7fd4552596800ef00e209d", null ],
      [ "WID_TN_SMALL_MAP", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6daec68b6bc12cf5129d2c8de99549cec9b", null ],
      [ "WID_TN_TOWNS", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6dae34a50c21c6c1291a4c5fdc40052bb58", null ],
      [ "WID_TN_SUBSIDIES", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6da21d25cd991bc3ec326df933c2b89f966", null ],
      [ "WID_TN_STATIONS", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6da90e5daf37b7b43e568ab88fbf5558f86", null ],
      [ "WID_TN_FINANCES", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6da81af434450cd3db0fce28c8abb13d3f9", null ],
      [ "WID_TN_COMPANIES", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6daa052d373764795aa53358827c8518fe6", null ],
      [ "WID_TN_STORY", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6da47043998fee70e896eaad0f10b2362dc", null ],
      [ "WID_TN_GOAL", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6da0dd413cb30f6b324c7d7cdb954c5d8d2", null ],
      [ "WID_TN_GRAPHS", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6da8d468c3d0b50e74454ad7ab404021b63", null ],
      [ "WID_TN_LEAGUE", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6da8f3fd3b05b0a6b3231c5d9f661b0c570", null ],
      [ "WID_TN_INDUSTRIES", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6daaeaff30e6af627866aafbaee3d6610ee", null ],
      [ "WID_TN_VEHICLE_START", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6da6cfe711c8201b4cc8afd25670a2c2c33", null ],
      [ "WID_TN_TRAINS", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6dae18567a541f973b03b0df3b6e6afab70", null ],
      [ "WID_TN_ROADVEHS", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6da6676cf7e9f13378157a18f0a70424292", null ],
      [ "WID_TN_SHIPS", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6da09ff010a1f25d4af37ae6933c8329ec6", null ],
      [ "WID_TN_AIRCRAFT", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6dab25a3e3dcd2c7f1590d6c4be54b2f262", null ],
      [ "WID_TN_ZOOM_IN", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6dabfdb6e034597b92ee93f27e5b71a36bb", null ],
      [ "WID_TN_ZOOM_OUT", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6dabe47e2bdcd2a369dcef030f1811913f8", null ],
      [ "WID_TN_BUILDING_TOOLS_START", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6da26455a32142433e764ceaead3fea2dd5", null ],
      [ "WID_TN_RAILS", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6da1fb55d5ea17f47f610332b05de1577ca", null ],
      [ "WID_TN_ROADS", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6dad7147b99eb0d0dd17cc42d1afeb338f2", null ],
      [ "WID_TN_WATER", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6dad6aef677cb5487f3182a0cdbfbe0bfd6", null ],
      [ "WID_TN_AIR", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6da09a0515b28e614316d58930f965b0db1", null ],
      [ "WID_TN_LANDSCAPE", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6da050bb359a40dc0f9a88dc4ee2489df5a", null ],
      [ "WID_TN_MUSIC_SOUND", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6da1ce721d644600101a068e5430f8dee98", null ],
      [ "WID_TN_MESSAGES", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6da488722523f726b8953d3934d29ae5d6a", null ],
      [ "WID_TN_HELP", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6da352de588956fbd69e23dac0e439a70b3", null ],
      [ "WID_TN_SWITCH_BAR", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6da977426a9d8db1822e5a77f52ecd9c336", null ],
      [ "WID_TN_END", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6da4124fdd1a74c80c4d1ab4b86d7140563", null ]
    ] ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d0/dd7/toolbar__widget_8h.js <==
var toolbar__widget_8h =
[
    [ "ToolbarEditorWidgets", "d0/dd7/toolbar__widget_8h.html#a17f63f9c72242c80963576f4a0b97212", [
      [ "WID_TE_PAUSE", "d0/dd7/toolbar__widget_8h.html#a17f63f9c72242c80963576f4a0b97212a805ae41c8137a5d797a8b7e912957bf6", null ],
      [ "WID_TE_FAST_FORWARD", "d0/dd7/toolbar__widget_8h.html#a17f63f9c72242c80963576f4a0b97212ac382fd8c6ca0514d1ce3ffa68d12794b", null ],
      [ "WID_TE_SETTINGS", "d0/dd7/toolbar__widget_8h.html#a17f63f9c72242c80963576f4a0b97212adbc7e6bfe4a3baaa031baababef63794", null ],
      [ "WID_TE_SAVE", "d0/dd7/toolbar__widget_8h.html#a17f63f9c72242c80963576f4a0b97212aa06efa62603dc3fcf7c7ad95b1133e14", null ],
      [ "WID_TE_SPACER", "d0/dd7/toolbar__widget_8h.html#a17f63f9c72242c80963576f4a0b97212a926fee6779bef9d3efaba8a5e877de71", null ],
      [ "WID_TE_DATE", "d0/dd7/toolbar__widget_8h.html#a17f63f9c72242c80963576f4a0b97212a449d244085ae7c380674dda54af4e907", null ],
      [ "WID_TE_DATE_BACKWARD", "d0/dd7/toolbar__widget_8h.html#a17f63f9c72242c80963576f4a0b97212af8db533879680a24e5d7bbf967c7c175", null ],
      [ "WID_TE_DATE_FORWARD", "d0/dd7/toolbar__widget_8h.html#a17f63f9c72242c80963576f4a0b97212a8ba2c217d52f421165e0ac0a4bfa4b07", null ],
      [ "WID_TE_SMALL_MAP", "d0/dd7/toolbar__widget_8h.html#a17f63f9c72242c80963576f4a0b97212a106965d81aa71b896943c76872d95ae4", null ],
      [ "WID_TE_ZOOM_IN", "d0/dd7/toolbar__widget_8h.html#a17f63f9c72242c80963576f4a0b97212a6ba70ed149bedaf0536939b5ff021487", null ],
      [ "WID_TE_ZOOM_OUT", "d0/dd7/toolbar__widget_8h.html#a17f63f9c72242c80963576f4a0b97212a773968404d558061e77747f74691c08b", null ],
      [ "WID_TE_LAND_GENERATE", "d0/dd7/toolbar__widget_8h.html#a17f63f9c72242c80963576f4a0b97212aa3a1e59d7e7623e673d6b93801a2a93e", null ],
      [ "WID_TE_TOWN_GENERATE", "d0/dd7/toolbar__widget_8h.html#a17f63f9c72242c80963576f4a0b97212aa757913f6adbd97afd7ec6ae30c22c2b", null ],
      [ "WID_TE_INDUSTRY", "d0/dd7/toolbar__widget_8h.html#a17f63f9c72242c80963576f4a0b97212a7fcfbe6deb0438f200108245c300ffd3", null ],
      [ "WID_TE_ROADS", "d0/dd7/toolbar__widget_8h.html#a17f63f9c72242c80963576f4a0b97212aaa20746aa0a5d3f13794c51c1fb92eb8", null ],
      [ "WID_TE_TRAMS", "d0/dd7/toolbar__widget_8h.html#a17f63f9c72242c80963576f4a0b97212a34396539bdd033078196dbf5be3633c4", null ],
      [ "WID_TE_WATER", "d0/dd7/toolbar__widget_8h.html#a17f63f9c72242c80963576f4a0b97212a94e700a5d6208bc0e8c1e9f3b172c6a5", null ],
      [ "WID_TE_TREES", "d0/dd7/toolbar__widget_8h.html#a17f63f9c72242c80963576f4a0b97212a148b4de732fe9bd096160c62fd1581ec", null ],
      [ "WID_TE_SIGNS", "d0/dd7/toolbar__widget_8h.html#a17f63f9c72242c80963576f4a0b97212ac590e6eec7efd51418d908421a318955", null ],
      [ "WID_TE_DATE_PANEL", "d0/dd7/toolbar__widget_8h.html#a17f63f9c72242c80963576f4a0b97212a6cbb415b5d9b075b02017e3e6199286f", null ],
      [ "WID_TE_MUSIC_SOUND", "d0/dd7/toolbar__widget_8h.html#a17f63f9c72242c80963576f4a0b97212a9b6f8a8f6fe85ad3aa4f7f5305a7ed4d", null ],
      [ "WID_TE_HELP", "d0/dd7/toolbar__widget_8h.html#a17f63f9c72242c80963576f4a0b97212a7259c24eb56d2f905e182ab0cd1fd643", null ],
      [ "WID_TE_SWITCH_BAR", "d0/dd7/toolbar__widget_8h.html#a17f63f9c72242c80963576f4a0b97212aa8245149e19ec5edb3ebaac63f4fc348", null ]
    ] ],
    [ "ToolbarNormalWidgets", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6d", [
      [ "WID_TN_PAUSE", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6dac08e4702de3440ac7d554be92cd6ad72", null ],
      [ "WID_TN_FAST_FORWARD", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6dabe5f09227a9d3d057c491f81deed8b45", null ],
      [ "WID_TN_SETTINGS", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6da0c055f87c6e8e0064475cbfb3f9f9beb", null ],
      [ "WID_TN_SAVE", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6da3cdb40d6ef7fd4552596800ef00e209d", null ],
      [ "WID_TN_SMALL_MAP", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6daec68b6bc12cf5129d2c8de99549cec9b", null ],
      [ "WID_TN_TOWNS", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6dae34a50c21c6c1291a4c5fdc40052bb58", null ],
      [ "WID_TN_SUBSIDIES", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6da21d25cd991bc3ec326df933c2b89f966", null ],
      [ "WID_TN_STATIONS", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6da90e5daf37b7b43e568ab88fbf5558f86", null ],
      [ "WID_TN_FINANCES", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6da81af434450cd3db0fce28c8abb13d3f9", null ],
      [ "WID_TN_COMPANIES", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6daa052d373764795aa53358827c8518fe6", null ],
      [ "WID_TN_STORY", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6da47043998fee70e896eaad0f10b2362dc", null ],
      [ "WID_TN_GOAL", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6da0dd413cb30f6b324c7d7cdb954c5d8d2", null ],
      [ "WID_TN_GRAPHS", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6da8d468c3d0b50e74454ad7ab404021b63", null ],
      [ "WID_TN_LEAGUE", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6da8f3fd3b05b0a6b3231c5d9f661b0c570", null ],
      [ "WID_TN_INDUSTRIES", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6daaeaff30e6af627866aafbaee3d6610ee", null ],
      [ "WID_TN_VEHICLE_START", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6da6cfe711c8201b4cc8afd25670a2c2c33", null ],
      [ "WID_TN_TRAINS", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6dae18567a541f973b03b0df3b6e6afab70", null ],
      [ "WID_TN_ROADVEHS", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6da6676cf7e9f13378157a18f0a70424292", null ],
      [ "WID_TN_SHIPS", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6da09ff010a1f25d4af37ae6933c8329ec6", null ],
      [ "WID_TN_AIRCRAFT", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6dab25a3e3dcd2c7f1590d6c4be54b2f262", null ],
      [ "WID_TN_ZOOM_IN", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6dabfdb6e034597b92ee93f27e5b71a36bb", null ],
      [ "WID_TN_ZOOM_OUT", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6dabe47e2bdcd2a369dcef030f1811913f8", null ],
      [ "WID_TN_BUILDING_TOOLS_START", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6da26455a32142433e764ceaead3fea2dd5", null ],
      [ "WID_TN_RAILS", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6da1fb55d5ea17f47f610332b05de1577ca", null ],
      [ "WID_TN_ROADS", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6dad7147b99eb0d0dd17cc42d1afeb338f2", null ],
      [ "WID_TN_TRAMS", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6da2a2d251dcb294f7183f7fc9ed55c30eb", null ],
      [ "WID_TN_WATER", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6dad6aef677cb5487f3182a0cdbfbe0bfd6", null ],
      [ "WID_TN_AIR", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6da09a0515b28e614316d58930f965b0db1", null ],
      [ "WID_TN_LANDSCAPE", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6da050bb359a40dc0f9a88dc4ee2489df5a", null ],
      [ "WID_TN_MUSIC_SOUND", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6da1ce721d644600101a068e5430f8dee98", null ],
      [ "WID_TN_MESSAGES", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6da488722523f726b8953d3934d29ae5d6a", null ],
      [ "WID_TN_HELP", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6da352de588956fbd69e23dac0e439a70b3", null ],
      [ "WID_TN_SWITCH_BAR", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6da977426a9d8db1822e5a77f52ecd9c336", null ],
      [ "WID_TN_END", "d0/dd7/toolbar__widget_8h.html#aef1aa292213e649f70f94c814ae7ef6da4124fdd1a74c80c4d1ab4b86d7140563", null ]
    ] ]
];
